@@ -39,7 +39,7 @@ struct _PrinterQueueWindowPrivate
   PrintingSystem *ps;
   gchar *printer;
 
-  XfceIconTheme *icontheme;
+  GtkIconTheme *icontheme;
   GtkUIManager *ui_manager;
   GtkActionGroup *action_group;
 
@@ -67,9 +67,9 @@ static GtkActionEntry action_entries[] = {
   {"printer-menu", NULL, N_("Printer"), NULL,},
   {"close", GTK_STOCK_CLOSE, N_("Close"), NULL, N_("Close queue window"), G_CALLBACK (action_close_cb),},
   {"jobs-menu", NULL, N_("Jobs"), NULL,},
-  {"remove-job", GTK_STOCK_REMOVE, N_("Remove job"), NULL, N_("Remove the selected job from the queue"),
+  {"remove-job", GTK_STOCK_REMOVE, N_("Remove job"), "Delete", N_("Remove the selected job from the queue"),
    G_CALLBACK (action_remove_job_cb),},
-  {"refresh", GTK_STOCK_REFRESH, N_("Refresh"), NULL, N_("Refresh queue"), G_CALLBACK (action_refresh_cb),},
+  {"refresh", GTK_STOCK_REFRESH, N_("Refresh"), "F5", N_("Refresh queue"), G_CALLBACK (action_refresh_cb),},
 };
 
 /*********/
@@ -112,19 +112,14 @@ printer_queue_window_init (PrinterQueueWindow * win)
   GtkTreeSelection *selection;
   GtkCellRenderer *cell;
   GtkTreeViewColumn *column;
-  GdkPixbuf *icon = NULL;
 
   priv = win->priv = PRINTER_QUEUE_WINDOW_GET_PRIVATE (win);
 
-  priv->icontheme = xfce_icon_theme_get_for_screen (NULL);
+  priv->icontheme = gtk_icon_theme_get_default ();
   g_signal_connect (G_OBJECT (priv->icontheme), "changed", G_CALLBACK (icon_theme_changed_cb), win);
 
   gtk_window_set_title (GTK_WINDOW (win), _("Queue Manager"));
-  icon = xfce_icon_theme_load (priv->icontheme, "xfprint", 48);
-  if (icon) {
-    gtk_window_set_icon (GTK_WINDOW (win), icon);
-    g_object_unref (icon);
-  }
+  gtk_window_set_icon_name (GTK_WINDOW (win), "printer");
   gtk_window_set_default_size (GTK_WINDOW (win), 450, 150);
   gtk_window_set_position (GTK_WINDOW (win), GTK_WIN_POS_NONE);
 
@@ -276,9 +271,9 @@ icon_theme_update_foreach_func (GtkTreeModel * model, GtkTreePath * path, GtkTre
     g_object_unref (icon);
 
   if (gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE_TOOLBAR, &x, &y))
-    icon = xfce_icon_theme_load (priv->icontheme, "gnome-mime-application-postscript", x);
+    icon = gtk_icon_theme_load_icon (priv->icontheme, "gnome-mime-application-postscript", x, 0, NULL);
   else
-    icon = xfce_icon_theme_load (priv->icontheme, "gnome-mime-application-postscript", 24);
+    icon = gtk_icon_theme_load_icon (priv->icontheme, "gnome-mime-application-postscript", 24, 0, NULL);
 
   gtk_list_store_set (GTK_LIST_STORE (model), iter, JOBS_ICON_COLUMN, icon, -1);
   g_object_unref (icon);
@@ -436,9 +431,9 @@ action_refresh_cb (GtkAction * action, PrinterQueueWindow * win)
     Job *job_data = (Job *) job->data;
 
     if (gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE_TOOLBAR, &x, &y))
-      icon = xfce_icon_theme_load (priv->icontheme, "gnome-mime-application-postscript", x);
+      icon = gtk_icon_theme_load_icon (priv->icontheme, "gnome-mime-application-postscript", x, 0, NULL);
     else
-      icon = xfce_icon_theme_load (priv->icontheme, "gnome-mime-application-postscript", 24);
+      icon = gtk_icon_theme_load_icon (priv->icontheme, "gnome-mime-application-postscript", 24, 0, NULL);
 
     string_id = g_strdup_printf ("%u", job_data->id);
     switch (job_data->state) {
